@@ -402,9 +402,10 @@ class Extraction(models.Model):
     @staticmethod
     def _total_price_db_func():
         return Sum(
-            Coalesce(F("ore_type__extras__refined_price"), 0)
+            Coalesce(F("ore_type__extras__refined_price"), 0.0)
             * F("volume")
-            / F("ore_type__volume")
+            / F("ore_type__volume"),
+            output_field=models.FloatField(),
         )
 
     def calc_is_jackpot(self) -> Optional[bool]:
@@ -469,6 +470,7 @@ class General(models.Model):
             ("view_all_moons", "Can view all known moons"),
             ("upload_moon_scan", "Can upload moon scans"),
             ("add_refinery_owner", "Can add refinery owner"),
+            ("view_moon_ledgers", "Can view moon ledgers"),
         )
 
 
@@ -568,7 +570,7 @@ class Moon(models.Model):
         return hasattr(self, "refinery")
 
     @cached_property
-    def products_sorted(self):
+    def products_sorted(self) -> models.QuerySet:
         """Return current products as sorted iterable."""
         try:
             return (
@@ -610,10 +612,11 @@ class Moon(models.Model):
     @staticmethod
     def _total_price_db_func():
         return Sum(
-            Coalesce(F("ore_type__extras__refined_price"), 0)
+            Coalesce(F("ore_type__extras__refined_price"), 0.0)
             * F("amount")
             * Value(float(MOONMINING_VOLUME_PER_MONTH))
-            / F("ore_type__volume")
+            / F("ore_type__volume"),
+            output_field=models.FloatField(),
         )
 
     def update_calculated_properties(self):
@@ -1161,23 +1164,24 @@ class Refinery(models.Model):
         )
         try:
             nearest_celestial = solar_system.nearest_celestial(
-                structure_info["position"]["x"],
-                structure_info["position"]["y"],
-                structure_info["position"]["z"],
+                x=structure_info["position"]["x"],
+                y=structure_info["position"]["y"],
+                z=structure_info["position"]["z"],
+                group_id=constants.EVE_GROUP_ID_MOON,
             )
         except OSError:
             logger.exception("%s: Failed to fetch nearest celestial ", self)
-        else:
-            if (
-                nearest_celestial
-                and nearest_celestial.eve_type.id == constants.EVE_TYPE_ID_MOON
-            ):
-                eve_moon = nearest_celestial.eve_object
-                moon, _ = Moon.objects.get_or_create(eve_moon=eve_moon)
-                self.moon = moon
-                self.save()
-                return True
-        return False
+            return False
+        if (
+            not nearest_celestial
+            or nearest_celestial.eve_type.id != constants.EVE_TYPE_ID_MOON
+        ):
+            return False
+        eve_moon = nearest_celestial.eve_object
+        moon, _ = Moon.objects.get_or_create(eve_moon=eve_moon)
+        self.moon = moon
+        self.save()
+        return True
 
     def update_moon_from_eve_id(self, eve_moon_id: int):
         eve_moon, _ = EveMoon.objects.get_or_create_esi(id=eve_moon_id)
