@@ -38,6 +38,11 @@ urlpatterns = [
         views.report_user_mining_data,
         name="report_user_mining_data",
     ),
+    path(
+        "report_user_uploaded_data",
+        views.report_user_uploaded_data,
+        name="report_user_uploaded_data",
+    ),
     path("modal_loader_body", views.modal_loader_body, name="modal_loader_body"),
     path("tests", views.tests, name="tests"),
 ]
